%global oldname letsencrypt

%bcond_without tests

Summary:        A free, automated certificate authority client
Name:           certbot
Version:        2.8.0
Release:        2%{?dist}
License:        Apache-2.0
URL:            https://github.com/certbot/certbot
Source0:        %{url}/archive/v%{version}/%{name}-%{version}.tar.gz

Source10:       certbot-renew-systemd.service
Source11:       certbot-renew-systemd.timer
Source12:       certbot-sysconfig-certbot
Source13:       certbot-cli.ini
Source14:       certbot.logrotate

BuildArch:      noarch

BuildRequires:  python3-devel
BuildRequires:  python3-pytest

%{?systemd_requires}
BuildRequires:  systemd

Requires(post): %{_sbindir}/restorecon

Requires: python3-certbot = %{version}-%{release}

%description
certbot is a free, automated certificate authority that aims
to lower the barriers to entry for encrypting all HTTP traffic on the internet.

%package -n python3-certbot
Summary:    Python 3 libraries used by certbot
Requires:   python3-acme

%package -n python3-acme
Summary:    Python library for the ACME protocol

%package -n python3-certbot-apache
Summary:    The apache plugin for certbot
Requires:   mod_ssl

Requires: python3-acme = %{version}-%{release}
Requires: python3-certbot = %{version}-%{release}


Provides:   certbot-apache = %{version}-%{release}


%package -n python3-certbot-nginx
Summary:     The nginx plugin for certbot
Provides:      certbot-nginx = %{version}-%{release}

Requires: python3-acme = %{version}-%{release}
Requires: python3-certbot = %{version}-%{release}

Recommends:    certbot >= %{version}


%description -n python3-certbot
The python3 libraries to interface with certbot

%description -n python3-acme
Python 3 library for use of the Automatic Certificate Management Environment
protocol as defined by the IETF. It's used by the Let's Encrypt project.

%description -n python3-certbot-apache
Plugin for certbot that allows for automatic configuration of apache

%description -n python3-certbot-nginx
Plugin for certbot that allows for automatic configuration of ngnix

%prep
%autosetup -n %{name}-%{version} -p1
# Remove bundled egg-info
rm -rf %{name}.egg-info

%generate_buildrequires
for module in acme certbot certbot-apache certbot-nginx
do
  cd $module
  sed -Ei '/(acme|certbot)>=\{version\}/d' setup.py
    %pyproject_buildrequires
  cd ..
done

%build
for module in acme certbot certbot-apache certbot-nginx
do
  cd $module
    %pyproject_wheel
  cd ..
done

%install
%pyproject_install


mv %{buildroot}%{_bindir}/certbot{,-3}

ln -s certbot %{buildroot}/usr/bin/%{oldname}
ln -s certbot-3 %{buildroot}%{_bindir}/certbot
install -Dm 0644 --preserve-timestamps %{SOURCE10} %{buildroot}%{_unitdir}/certbot-renew.service
install -Dm 0644 --preserve-timestamps %{SOURCE11} %{buildroot}%{_unitdir}/certbot-renew.timer
install -Dm 0644 --preserve-timestamps %{SOURCE12} %{buildroot}%{_sysconfdir}/sysconfig/certbot
install -Dm 0644 --preserve-timestamps %{SOURCE13} %{buildroot}%{_sysconfdir}/letsencrypt/cli.ini
install -Dm 0644 --preserve-timestamps %{SOURCE14} %{buildroot}%{_sysconfdir}/logrotate.d/certbot

install -dm 0755 %{buildroot}%{_sysconfdir}/%{oldname}
install -dm 0755 %{buildroot}%{_sharedstatedir}/%{oldname}
install -dm 0755 %{buildroot}%{_localstatedir}/log/letsencrypt

%if %{with tests}
%check
for module in acme certbot certbot-apache certbot-nginx; do
pushd $module
%pytest -v
popd
done
%endif


%post
restorecon -R %{_sysconfdir}/letsencrypt || :
%systemd_post certbot-renew.timer

# Remind users to start certbot-renew.timer if they need certbot to automatically renew certs
if [ "$1" -eq 1 ] ; then
  echo ""
  echo "Certbot auto renewal timer is not started by default."
  echo "Run 'systemctl start certbot-renew.timer' to enable automatic renewals."
fi

%preun
%systemd_preun certbot-renew.timer


%postun
%systemd_postun certbot-renew.timer


%files -n certbot
%license LICENSE.txt
%doc certbot/README.rst certbot/CHANGELOG.md
%{_bindir}/certbot
%{_bindir}/%{oldname}
%dir %{_sysconfdir}/%{oldname}
%dir %{_sharedstatedir}/%{oldname}
%dir %{_localstatedir}/log/letsencrypt
%config(noreplace) %{_sysconfdir}/%{oldname}/cli.ini
%config(noreplace) %{_sysconfdir}/sysconfig/certbot
%config(noreplace) %{_sysconfdir}/logrotate.d/certbot
%{_unitdir}/certbot-renew.service
%{_unitdir}/certbot-renew.timer


%files -n python3-certbot
%license certbot/LICENSE.txt
%doc certbot/README.rst certbot/CHANGELOG.md
%{_bindir}/certbot-3
%{python3_sitelib}/certbot/
%{python3_sitelib}/certbot-%{version}.dist-info/


%files -n python3-acme
%license acme/LICENSE.txt
%doc acme/README.rst
%{python3_sitelib}/acme/
%{python3_sitelib}/acme-%{version}.dist-info/


%files -n python3-certbot-apache
%license certbot-apache/LICENSE.txt
%doc certbot-apache/README.rst
%{python3_sitelib}/certbot_apache/
%{python3_sitelib}/certbot_apache-%{version}.dist-info/


%files -n python3-certbot-nginx
%license certbot-nginx/LICENSE.txt
%doc certbot-nginx/README.rst
%{python3_sitelib}/certbot_nginx/
%{python3_sitelib}/certbot_nginx-%{version}.dist-info/


%changelog
* Wed Jan 17 2024 Rebuild Robot <rebot@opencloudos.org> - 2.8.0-2
- Rebuilt for python-setuptools

* Wed Jan 17 2024 Shuo Wang <abushwang@tencent.com> - 2.8.0-1
- update to 2.8.0

* Tue Sep 19 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.6.0-4
- Rebuilt for python 3.11

* Wed Sep 13 2023 cunshunxia <cunshunxia@tencent.com> - 2.6.0-3
- skip test deprecated for py311

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.6.0-2
- Rebuilt for OpenCloudOS Stream 23.09

* Mon Aug 28 2023 Yi Lin <nilusyi@tencent.com> - 2.6.0-1
- package init.
